@@ -57,15 +57,6 @@ gboolean disable_uninstalled = FALSE;
 gboolean ignore_requires = FALSE;
 gboolean ignore_private_libs = TRUE;
 
-static Package pkg_config_package = {
-  .key = PACKAGE,
-  .name = PACKAGE,
-  .version = VERSION, /* .version */
-  .description = "returns metainformation about installed libraries",
-  .url = "http://pkg-config.freedesktop.org",
-  0 /* keep the rest as null */
-};
-
 void
 add_search_dir (const char *path)
 {
@@ -188,7 +179,7 @@ scan_dir (const char *dirname)
 
       if (ends_in_dotpc (dent->d_name))
         {
-          char *pkgname = malloc (len - 2);
+          char *pkgname = g_malloc (len - 2);
 
           debug_spew ("File '%s' appears to be a .pc file\n", dent->d_name);
           
@@ -284,9 +275,6 @@ internal_get_package (const char *name, gboolean warn, gboolean check_compat)
   Package *pkg = NULL;
   const char *location;
   
-  if (strcmp(PACKAGE, name) == 0)
-    return &pkg_config_package;
-
   pkg = g_hash_table_lookup (packages, name);
 
   if (pkg)
@@ -483,7 +471,23 @@ string_list_to_string (GSList *list)
   tmp = list;
   while (tmp != NULL)
     {
-      g_string_append (str, tmp->data);
+      char *tmpstr = (char*) tmp->data;
+      if (pcsysrootdir != NULL)
+	{
+	  if (tmpstr[0] == '-' &&
+	      (tmpstr[1] == 'I' ||
+	       tmpstr[1] == 'L'))
+	    {
+	      g_string_append_c (str, '-');
+	      g_string_append_c (str, tmpstr[1]);
+	      g_string_append (str, pcsysrootdir);
+	      g_string_append (str, tmpstr+2);
+	    }
+	}
+      else 
+	{
+	  g_string_append (str, tmpstr);
+	}
       g_string_append_c (str, ' ');
       
       tmp = g_slist_next (tmp);
@@ -617,7 +621,7 @@ recursive_fill_list (Package *pkg, GetListFunc func, GSList **listp)
 
   fill_one_level (pkg, func, listp);
   
-  tmp = pkg->requires;
+  tmp = (*func) (pkg);
 
   while (tmp != NULL)
     {
@@ -821,7 +825,7 @@ verify_package (Package *pkg)
    */
   
   recursive_fill_list (pkg, get_requires_private, &requires);
-  recursive_fill_list (pkg, get_conflicts, &conflicts);
+  conflicts = get_conflicts (pkg);
 
   requires_iter = requires;
   while (requires_iter != NULL)
@@ -843,7 +847,7 @@ verify_package (Package *pkg)
                              req->version, req->name,
                              ver->name,
                              comparison_to_str (ver->comparison),
-                             ver->version,
+                             ver->version ? ver->version : "(any)",
                              ver->owner->name,
                              ver->owner->version);
 
@@ -857,7 +861,6 @@ verify_package (Package *pkg)
     }
   
   g_slist_free (requires);
-  g_slist_free (conflicts);
 
   /* We make a list of system directories that gcc expects so we can remove
    * them.
